@@ -33,8 +33,6 @@ class Data_Organizer(object):
     def run(self, seg_path, img_path_list, index, modality = ['CT']):
         seg = sitk.ReadImage(seg_path)
         save_dict = dict()
-        if self.resampling != None:
-            save_dict['target_spacing'] = self.resampling.target_spacing
         save_dict['spacing'] = seg.GetSpacing()
         save_dict['direction'] = seg.GetDirection()
         save_dict['origin'] = seg.GetOrigin()
@@ -72,16 +70,20 @@ class Data_Organizer(object):
 
         
 
-        if self.resample != None:
-            y = torch.tensor(seg_arr.copy())
-            x = torch.tensor(img_arr.copy())
+        if self.resampling != None:
+            if isinstance(img_arr, np.ndarray):
+                x = torch.tensor(img_arr.copy())
+            
+            if isinstance(seg_arr, np.ndarray):
+                y = torch.tensor(seg_arr.copy())
+                
             if self.mode == 'train' :
-                result = self.resample(torch.vstack((x, y.unsqueeze(0))), save_dict)
+                result = self.resampling(torch.vstack((x, y.unsqueeze(0))), save_dict)
                 x = result[:-1]
                 y = result[-1].squeeze(0)
             
             else:
-                x = self.resample(x, save_dict)
+                x = self.resampling(x, save_dict)
 
         np.savez(os.path.join(self.SAVE_PATH, self.ID+str(index)+'.npz'), x =img_arr.numpy(), y=seg_arr.numpy())
 
