@@ -8,6 +8,7 @@ def is_overlap(points, current_point):
     else:
         return False
 
+"""
 def get_random_sample(points, candidates, batch_index):
     n_candidates = len(candidates[0])
     index = np.random.choice(np.arange(n_candidates), size = (n_candidates,), replace = False)
@@ -28,6 +29,20 @@ def get_random_sample(points, candidates, batch_index):
     if not is_overlap(points, point):
         points[point[0], point[1], point[2], point[3]] = 1
     return points
+"""
+
+
+def get_random_sample(points, candidates, batch_index):
+    n_candidates = len(candidates[0])
+    index = np.random.choice(np.arange(n_candidates), size = (1,), replace = False)
+
+    x = candidates[-3][index[0]]
+    y = candidates[-2][index[0]]
+    z = candidates[-1][index[0]]
+    
+    point = [batch_index, x, y, z]
+    points[point[0], point[1], point[2], point[3]] = 1
+    return points
 
 def point_sampler(target, output = None, positive_points = None, negative_points = None):
     # target shpae, prev_seg => (batch, x, y, z)
@@ -54,12 +69,16 @@ def point_sampler(target, output = None, positive_points = None, negative_points
         elif prev_seg[batch_index].sum() >= target[batch_index].sum():
             # negative sampling
             candidates = torch.where((target * (prev_seg != target)) == 0)
-            negative_points = get_random_sample(negative_points, candidates, batch_index)
+            n_candidates = len(candidates[0])
+            index = torch.randint(low = 0, high = n_candidates, size = (1,))
+            negative_points[batch_index, candidates[-3][index], candidates[-2][index],candidates[-1][index]] = 1
 
         elif prev_seg[batch_index].sum() < target[batch_index].sum():
             # positive sampling
             candidates = torch.where((target * (prev_seg != target)) == 1)
-            positive_points = get_random_sample(positive_points, candidates, batch_index)
+            n_candidates = len(candidates[0])
+            index = torch.randint(low = 0, high = n_candidates, size = (1,))
+            positive_points[batch_index, candidates[-3][index], candidates[-2][index],candidates[-1][index]] = 1
 
     
     return positive_points, negative_points
