@@ -2,6 +2,7 @@ from torch.utils.tensorboard import SummaryWriter
 import torch.optim as optim
 from torch.utils.data import random_split
 import torch
+import time
 from ingradient_library.dataloads import *
 from ingradient_library.model import *
 from ingradient_library.preprocessing import *
@@ -38,6 +39,7 @@ class Trainer(object):
             output = output.reshape(batch_size * deep_supervision_size, channel_size, -1)
             target = target.reshape(batch_size, 1, -1).repeat(1, deep_supervision_size,1).reshape(batch_size * deep_supervision_size, -1)
             weight = torch.ones(deep_supervision_size).to(output.device.index)
+            weight.requires_grad = False
             acc_value = self.deep_supervision_weight
             for i in range(deep_supervision_size):
                 weight[i] = acc_value ** i
@@ -176,17 +178,27 @@ class Interactive_Trainer(Trainer):
                 self.optimizer.step()
 
                 for i in range(self.n_point):
+                    zero_grad = time.time()
                     self.optimizer.zero_grad()
-                    positive_points, negative_points = point_sampler(seg, output, positive_points, negative_points)
-                    output = self.model(images, positive_points, negative_points, output)
+                    print('zero grad', time.time() - zero_grad)
+                    prev_seg_time = time.time()
+                    prev_seg = output.detach()
+                    print('prev_seg', time.time()- prev_seg_time)
+                    ps_time = time.time()
+                    positive_points, negative_points = point_sampler(seg, prev_seg, positive_points, negative_points)
+                    out_time = time.time
+                    print('ps time', time.time()- ps_time)
+                    output = self.model(images, positive_points, negative_points, prev_seg)
+                    loss_time = time.time()
+                    print('out time', time.time()- out_time)
                     loss = self.calculate_loss(output, seg, writer, e)
                     train_loss = loss.item()
                     if self.tr_dl.current_index % visualization_ineterval == 0:
                         print("points : ",i + 1)
                         visualization(output, seg)
-                    writer.add_scalar('Loss/clicks_'+str(i+1), train_loss)
                     loss.backward()
                     self.optimizer.step()
+                    print('out time', time.time()- loss_time)
             self.scheduler.step()
 
 
